.. moldoc-test documentation master file, created by
   sphinx-quickstart on Fri Jul 30 17:53:00 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to moldoc-test's documentation!
=======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:


Some content but no moldoc directive


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
